tdub.root
---------

A module for working with ROOT-like objects (without ROOT itself).

.. currentmodule:: tdub.root

Class Summary
^^^^^^^^^^^^^

.. autosummary::

   TH1
   TGraphAsymmErrors

Reference
^^^^^^^^^

.. autoclass:: TH1
   :members:
.. autoclass:: TGraphAsymmErrors
   :members:
